# Argparse Param Types
## Introduction

Argparse is an excelent standard library for managing input in command-line python script but it ships with only basic types. This project provides a library of option types that covers a lot of common use case to avoid rewriting again and again the same basic code.

## Installation

```
pip install argparse_param_types
```

## How to use


## Available option types


## Changelog


## License

[MIT License](https://opensource.org/licenses/MIT) © [ndmalc]